@@ -1,10 +1,10 @@
 from .api import *
 from .version import __version__
-from .module import FaceDetector as module
+from .module import FaceDetector
 
 from . import adapter
 from . import dataset
-from . import datamodule
 from . import metric
-from . import transform
-from . import utils
\ No newline at end of file
+from . import transforms
+from . import utils
+from . import loss
